/****************************************************************************
 Copyright (c) 2011-2012 cocos2d-x.org
 Copyright (c) 2013-2014 Chukong Technologies Inc.

 http://www.cocos2d-x.org

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 ****************************************************************************/
/**
 * <p>cc.LoaderScene is a scene that you can load it when you loading files</p>
 * <p>cc.LoaderScene can present thedownload progress </p>
 * @class
 * @extends cc.Scene
 * @example
 * var lc = new cc.LoaderScene();
 */

cc.loadScene = cc.Scene.extend({
    _interval : null,
    _label : null,
    _className:"loadScene",
    _musicLoadCount : 0,
    _allMusicPreload : false,

    _allPictureCount : 0,
    _allPicturePreload : false,
    _pictureLoadCount : 0,


    allLoadedEnd : false,
    /**
     * Contructor of cc.loadScene
     * @returns {boolean}
     */
    init : function(){
        var self = this;

        //logo
        var logoWidth = 160;
        var logoHeight = 200;

        //前后排云精灵载体
        var sprite = new cc.Sprite();
        var sprite2 = new cc.Sprite();

        var bgLayer = display.newSprite(loadRes.loadingBg)
        bgLayer.x = 640;
        bgLayer.y = 360;
        bgLayer.setScale(2, 2);
        self.addChild(bgLayer);     

        self.addChild(sprite);

        cc.spriteFrameCache.addSpriteFrames(resObj["common"].dingdong_plist);

        self.dingdong = display.newBone(loadRes.dingdong_json, "dingdong");
        self.dingdong.x = 640;
        self.dingdong.y = -360;
        self.dingdong.setScale(1.4);
        self.addChild(self.dingdong);
        self.dingdong.getAnimation().play("fly");

        var fontSize = 24, lblHeight =  -logoHeight / 2 + 100;

        self.addChild(sprite2);

        self.dingdong.runAction(cc.moveTo(0.5, 640, 360))


        var spriteLayerList = [sprite,sprite2];

        //云精灵数组
        var spriteList = [];
        var spriteList2 = [];
        var spriteAllList = [spriteList,spriteList2];

        //云精灵坐标
        var dataList = [[-720,0,720,1440],[-1440,1400]];//[[720,0,-720,-1440],[1440,-1400]];
        var cs = dataList[0].length;

        //云精灵移动一个屏幕高度所需时间
        var timeList = [3,0.6];

        //云坐标大小
        var cloudDateList = [{x:173.5,y:111,scale:1},{x:268.5,y:547,scale:1},{x:619,y:339,scale:1},
                            {x:917.5,y:127,scale:1},{x:1050.5,y:466,scale:1}];

        var cloudDateList2 = [{x:328.5,y:491,scale:1.5},{x:968.5,y:231,scale:1.5}];
        
        //制造云的载体精灵
        var sprtieFun = function(y,index){
            var sprite = new cc.Sprite();
            sprite.x = 0;
            sprite.y = y;
            spriteLayerList[index].addChild(sprite);
            spriteAllList[index].push(sprite);
            return sprite;
        }          

        //制造云
        var cloudFun = function(parent,x,y,scale){
            var ob = new cc.Sprite(loadRes.loadingCloud);
            ob.x = x;
            ob.y = 720 - y;
            ob.setScale(scale,scale);
            ob.opacity = 200;
            parent.addChild(ob);
            return ob;
        };

        //云精灵做的运动
        var twFun = function(ob,index){
            var y1 = ob.y;
            var js = dataList[1][0];
            var ks = dataList[1][1];
            var cs1 = Math.abs((js - y1)/720);
            var ti = timeList[index];

            if(cs == cs1){
                ob.runAction(cc.sequence(
                    cc.moveTo(cs1*ti, 0, js),
                    cc.callFunc(function(){
                        ob.y = ks;
                    })
                ).repeatForever()
                );

            }else{
                ob.runAction(cc.sequence(
                    cc.moveTo(cs1*ti, 0, js),
                    cc.callFunc(function(){
                        ob.y = ks;
                    }),
                    cc.moveTo((cs - cs1)*ti, 0, y1)
                ).repeatForever()
                );

            }     
        }

        //正负随机数
        var randomFun = function(r){
            var index = r*Math.random();
            return Math.random()>.5 ? -1*index : 1*index;
        }

        for(var i = 0; i < cs; i++){
            sprtieFun(dataList[0][i],0);
            sprtieFun(dataList[0][i],1);
        }


        for(var j = 0; j < cs; j++){
            
            for(var i = 0; i < cloudDateList.length; i++){

                var xx = randomFun(50);
                var yy = randomFun(50);
                
                var ob = cloudFun(spriteList[j],cloudDateList[i].x + xx,cloudDateList[i].y + yy,cloudDateList[i].scale);
            }
            for(var i = 0; i < cloudDateList2.length; i++){

                var xx = randomFun(50);
                var yy = randomFun(50);

                var ob = cloudFun(spriteList2[j],cloudDateList2[i].x + xx,cloudDateList2[i].y + yy,cloudDateList2[i].scale);
            }
        }

        for(var i = 0; i < cs; i++){
            twFun(spriteList[i],0);
            twFun(spriteList2[i],1);
        }

        sound.stopAllEffectsAndMusic();

        return true;
    },

    /**
     * custom onEnter
     */
    onEnter: function () {
        var self = this;

        cc.Node.prototype.onEnter.call(self);
        self.schedule(self._loadingStartLoading, 0.3);
    },
    /**
     * custom onExit
     */
    onExit: function () {
        cc.Node.prototype.onExit.call(this);
        var tmpStr = " 0%";
        //this._label.setString(tmpStr);
    },

    /**
     * init with resources
     * @param {Array} resources
     * @param {Function|String} cb
     */
    initWithResources: function (resources, cb) {
        if(cc.isString(resources))
            resources = [resources];
        this.resources = resources || [];
        this.cb = cb;
    },

    runStartScene: function(){
        var self = this;

        self.dingdong.runAction(cc.sequence(
            cc.moveTo(0.5, 640, 1080),
                cc.callFunc(function(){
                if(Map_GameIndex == "0_0_0"){
                    if(window.localStorage["mapName"] && window.localStorage["mapName"] != "map0"){
                        cc.director.runScene(new SceneC_SubMap(window.localStorage["mapName"]));
                    }else{
                        cc.director.runScene(new SceneC());
                    } 
                }else{
                    game.index = 0;
                    cc.director.runScene(new SceneC());
                }                                                                                                
                })
            )) 
    },

    _loadingStartLoading: function () {
        // if(sound.resourceLength !== 0){
        //     window.location.href = sound.iosUrl + sound.resourceUrls;
        // }
        var self = this;

        self.unschedule(self._loadingStartLoading);
        var res = self.resources;

        cc.loader.load(res,
            function (result, count, loadedCount) {
                //如果是安卓 sound.resourceLength 为0，count 即为全部资源的总和
                self._pictureLoadCount = loadedCount;
                self._allPictureCount = count;
			
                //var percent = ((self._pictureLoadCount + self._musicLoadCount+1) / (self._allPictureCount + sound.resourceLength) * 100) | 0;
                //var percent = ((self._pictureLoadCount + self._musicLoadCount+1) / (self._allPictureCount) * 100) | 0;
                
				//percent = Math.min(percent, 100);
                //self._label.setString(" " + percent + "%");

                //self.bar2.setPercent(percent);
                //self.dingdongSister.x = 240 + percent*8;
            
            }, function () {
                if (self.cb){
                    self._allPicturePreload = true;
                        self.cb();
                        // groupGame.gameIndex = window.location.href.match("\/[^\/]+\/([^\/]*)\/[^\/]*$")[1];
                        groupGame.gameIndex = Map_GameIndex;

                        var gameList;
                        if(Map_Category === 'experience'){
                            gameList = groupGame.gameLixinList[groupGame.gameIndex];
                        }
                        else if(Map_Category === 'math'){
                            gameList = groupGame.gameLuojiList[groupGame.gameIndex];
                        }
                        else if(Map_Category === "evaluation"){
                            gameList = groupGame.gameEvaluationList[groupGame.gameIndex];
                        }
                        else{
                            gameList = groupGame.gameEvaluationList[groupGame.gameIndex];
                        }

                        if(gameList instanceof Array && gameList.length >= 2){
                            groupGame.initOtherResources(function(){
                                groupGame.loadOtherResources();
                            });
                        }
                    

                        if (browser.versions.android) {
                            
                            self.runStartScene();
                        }
                        else {
                            var startButton = display.newSprite("../10001/res/common/tips.png")
                            startButton.x = 640;
                            startButton.y = 250;
                            self.addChild(startButton);

                            startButton.runAction(cc.sequence(
                                cc.scaleTo(0.5, 1),
                                cc.scaleTo(0.5, 0.9)
                            ).repeatForever())

                            var hand = display.newSprite("../10001/res/common/hand.png")
                            hand.x = 680;
                            hand.y = 190;
                            self.addChild(hand);

                            hand.runAction(cc.sequence(
                                cc.scaleTo(0.5, 0.9),
                                cc.scaleTo(0.5, 1)
                            ).repeatForever())

                            var startButtonTouchListener = cc.EventListener.create({
                                //event: cc.EventListener.TOUCH_ONE_BY_ONE,TOUCH_ALL_AT_ONCE
                                event: cc.EventListener.TOUCH_ONE_BY_ONE,
                                swallowTouches: true,
                                onTouchBegan: function(touch, event){
                                    var target = event.getCurrentTarget();
                                    var locationInNode = target.convertToNodeSpace(touch.getLocation());
                                    var s = target.getContentSize();
                                    var rect = cc.rect(-20, -20, s.width + 40, s.height + 40);
                                    if (cc.rectContainsPoint(rect, locationInNode)) {
                                        if(self.allLoadedEnd === true){
                                            startButton.setVisible(false);
                                            hand.setVisible(false);
                                            
                                            cc.audioEngine.playEffect(loadRes.button);

                                            self.runStartScene();                                                                        
                                            
                                            return true;
                                        }
                                        
                                    }
                                    return false;
                                },
                                onTouchMoved: function(touch, event){
                                    var target = event.getCurrentTarget();
                                    var delta = touch.getDelta();
                                },
                                onTouchEnded:function(touch, event){
                                    var target = event.getCurrentTarget();
                                }
                            });
                            cc.eventManager.addListener(startButtonTouchListener, startButton);
                        }
                        
                        self.allLoadedEnd = true;
                }
            });
    }
});
/**
 * <p>cc.LoaderScene.preload can present a loaderScene with download progress.</p>
 * <p>when all the resource are downloaded it will invoke call function</p>
 * @param resources
 * @param cb
 * @returns {cc.LoaderScene|*}
 * @example
 * //Example
**/
//cc.loadScene.preload(g_resources, function () {
//    cc.director.runScene(new cc.loaderScene());
//}, this);

cc.loadScene.preload = function(resources , cb){
    var _cc = cc;
    window['removeImg']();
    if(!_cc.loaderScene) {
        _cc.loaderScene = new cc.loadScene();
        _cc.loaderScene.init();

        document.getElementById("gameCanvas").style.display = "";

    }

    _cc.loaderScene.initWithResources(resources, cb);

    cc.director.runScene(_cc.loaderScene);

    return _cc.loaderScene;
};